BlockLink extension

Builds deep links to a block within a known object.

on

Methods

Available on Block, provided by the BlockLink extension

The deep link to this block, or null if it has no id (e.g. a new, not-yet-saved block).