CapacitiesLink class

A parsed Capacities desktop app deep link: capacities://<spaceId>/<objectId> or capacities://<spaceId>/<objectId>?bid=<blockId>.

Constructors

CapacitiesLink({required String spaceId, required String objectId, String? blockId})
const
CapacitiesLink.parse(String link)
Parses a capacities:// deep link. Throws FormatException if link isn't a valid Capacities deep link.
factory

Properties

blockId String?
final
hashCode int
The hash code for this object.
no setteroverride
objectId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spaceId String
final

Methods

build() String
Builds the capacities:// deep link string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

tryParse(String link) CapacitiesLink?
Like CapacitiesLink.parse, but returns null instead of throwing on invalid input.